<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>ファイルツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>表示ファイルツール</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;F ファイル</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>フォーマット:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translation>ファイルを上書きしますか?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>ファイル&apos;%1&apos;は既に存在します。 上書きしますか?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
